"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _controllerGeneric = _interopRequireDefault(require("../generic/controller-generic"));

var _auth = _interopRequireDefault(require("./auth.service"));

var _express = require("express");

var _passport = _interopRequireDefault(require("passport"));

var _jsonwebtoken = _interopRequireDefault(require("jsonwebtoken"));

var _boom = _interopRequireDefault(require("@hapi/boom"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AuthController extends _controllerGeneric.default {
  constructor() {
    super(_auth.default, false);
  }

  routes() {
    const router = new _express.Router();
    router.post('/login', this.login);
    router.post('/register', (req, res, next) => {
      this.register(req, res, next);
    });
    router.get('/profile', _passport.default.authenticate('jwt'), this.profile);
    return router;
  }

  login(req, res, next) {
    _passport.default.authenticate('local', {
      session: false
    }, (err, user, info) => {
      if (err) {
        next(err);
      } else {
        req.login(user, {
          session: false
        }, err => {
          if (err) {
            next(err);
          } else {
            // generate a signed son web token with the contents of user object and return it in the response
            const token = _jsonwebtoken.default.sign(user, process.env.APP_AUTH_SECRET);

            return res.json({
              user,
              token
            });
          }
        });
      }
    })(req, res);
  }

  register(req, res, next) {
    return this.service.register(req.body).then(data => res.json(data)).catch(err => next(err));
  }

  profile(req, res) {
    res.json(req.user);
  }

}

exports.default = AuthController;