"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _boom = _interopRequireDefault(require("@hapi/boom"));

var _serviceGeneric = _interopRequireDefault(require("../generic/service-generic"));

var _password = require("../utils/password");

var _auth = _interopRequireDefault(require("./auth.repository"));

var _package = _interopRequireDefault(require("../../../package"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class AuthService extends _serviceGeneric.default {
  constructor() {
    super(_auth.default, "Auth");
  }

  login(username, password) {
    return this.repository.findUserByUsernameField(username).then(userInDb => {
      if (!userInDb) {
        throw _boom.default.notFound("Usuário não encontrado", {
          key: 'USUARIO_NAO_ENCONTRADO'
        });
      }

      const userInDbObj = userInDb.toJSON();
      let passwordIsValid = (0, _password.isValidPassword)(password, userInDbObj[_package.default.junsApi.auth.passwordField]);

      if (!passwordIsValid) {
        throw _boom.default.badImplementation("Senha incorreta", {
          key: 'SENHA_INCORRETA'
        });
      }

      return userInDbObj;
    });
  }

  register(user) {
    return this.repository.findUserByUsernameField(user[_package.default.junsApi.auth.usernameField]).then(userInDb => {
      if (userInDb) {
        throw _boom.default.badImplementation("Já exite um usuário com este e-mail cadastrado.", {
          key: 'EMAIL_JA_CADASTRADO'
        });
      }

      user[_package.default.junsApi.auth.passwordField] = (0, _password.encryptPassword)(user[_package.default.junsApi.auth.passwordField]);
      return this.repository.inserir(user);
    });
  }

}

exports.default = AuthService;