"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _ejs = _interopRequireDefault(require("ejs"));

var _nodemailer = _interopRequireDefault(require("nodemailer"));

var _boom = _interopRequireDefault(require("@hapi/boom"));

var _domain = require("./utils/domain");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function checkParameters() {
  return !process.env.MAIL_SMTP || !process.env.MAIL_SMTP_PORT || !process.env.MAIL_USER || !process.env.MAIL_PASSWORD;
}

function sendEmail(to, cc, subject, html) {
  const transporter = _nodemailer.default.createTransport({
    host: process.env.MAIL_SMTP,
    port: process.env.MAIL_SMTP_PORT,
    secure: process.env.MAIL_SMTP_SECURE,
    auth: {
      user: process.env.MAIL_USER,
      pass: process.env.MAIL_PASSWORD
    }
  });

  const mailOptions = {
    from: process.env.MAIL_USER,
    to: to,
    cc: cc,
    subject: subject,
    html
  };
  return transporter.sendMail(mailOptions);
}

function prepareTemplate(templateName, parameters, callback) {
  const filePath = "./src/template/email/" + templateName;
  const resolvedPath = path.resolve(filePath);

  if (!parameters.link) {
    parameters.link = (0, _domain.mountDomain)();
  }

  _ejs.default.renderFile(resolvedPath, parameters, callback);
}

function _default(to, cc, subject, templateName, parameters) {
  if (checkParameters()) {
    throw _boom.default.internal("SMTP não configurado");
  }

  prepareTemplate(templateName, parameters, function (err, html) {
    if (err) {
      return err;
    } else {
      sendEmail(to, cc, subject, html).then(info => {
        console.error("Message %s sent: %s", info.messageId, info.response);
      }).catch(error => {
        console.error(error);
      });
    }
  });
}