"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _httpStatusCodes = _interopRequireDefault(require("http-status-codes"));

var _express = require("express");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

class ControllerGeneric {
  constructor(service, hasCrudRoutes = true) {
    this.serviceClass = service;
    this.service = new service();
    this.hasCrudRoutes = hasCrudRoutes;
  }

  routesOfCrud() {
    const router = new _express.Router();

    if (this.hasCrudRoutes) {
      router.get("/", (req, res, next) => {
        this.buscarTodos(req, res, next);
      });
      router.get("/:key", (req, res, next) => {
        this.validarExistenciaModel(req, res, next);
      }, (req, res, next) => {
        this.buscarPorId(req, res, next);
      });
      router.post("/", (req, res, next) => {
        this.inserir(req, res, next);
      });
      router.put("/:key", (req, res, next) => {
        this.validarExistenciaModel(req, res, next);
      }, (req, res, next) => {
        this.editar(req, res, next);
      });
      router.delete("/:key", (req, res, next) => {
        this.validarExistenciaModel(req, res, next);
      }, (req, res, next) => {
        this.remover(req, res, next);
      });
    }

    return router;
  }

  routes() {
    return new _express.Router();
  }

  getAllroutes() {
    const router = (0, _express.Router)();
    router.use(this.routesOfCrud());
    router.use(this.routes());
    return router;
  }

  getService() {
    return new this.serviceClass();
  }

  buscarTodos(req, res, next) {
    this.service.buscarTodos().then(data => res.json({
      data
    })).catch(err => next(err));
  }

  buscarPorId(req, res, next) {
    this.service.buscarPorId(req.params.key).then(data => res.json({
      data
    })).catch(err => next(err));
  }

  inserir(req, res, next) {
    this.service.inserir(req.body).then(data => res.status(_httpStatusCodes.default.CREATED).json({
      data
    })).catch(err => next(err));
  }

  editar(req, res, next) {
    this.service.editar(req.params.key, req.body).then(data => res.json({
      data
    })).catch(err => next(err));
  }

  remover(req, res, next) {
    this.service.remover(req.params.key).then(data => res.status(_httpStatusCodes.default.NO_CONTENT).json({
      data
    })).catch(err => next(err));
  }

  validarExistenciaModel(req, res, next) {
    return this.service.buscarPorId(req.params.key).then(() => next()).catch(err => next(err));
  }

}

exports.default = ControllerGeneric;