"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

require("./env");

require("./database");

var _cors = _interopRequireDefault(require("cors"));

var _raven = _interopRequireDefault(require("raven"));

var _helmet = _interopRequireDefault(require("helmet"));

var _morgan = _interopRequireDefault(require("morgan"));

var _express = _interopRequireDefault(require("express"));

var _routes = _interopRequireDefault(require("./routes"));

var _bodyParser = _interopRequireDefault(require("body-parser"));

var _compression = _interopRequireDefault(require("compression"));

var _json = _interopRequireDefault(require("./middlewares/json"));

var _logger = _interopRequireWildcard(require("./utils/logger"));

var _domain = require("./utils/domain");

var errorHandler = _interopRequireWildcard(require("./middlewares/errorHandler"));

var _package = _interopRequireDefault(require("../../package"));

var _passport = _interopRequireDefault(require("./passport"));

var _auth = _interopRequireDefault(require("./auth/auth.controller"));

var _fileUpload = _interopRequireDefault(require("./fileUpload"));

function _interopRequireWildcard(obj) { if (obj && obj.__esModule) { return obj; } else { var newObj = {}; if (obj != null) { for (var key in obj) { if (Object.prototype.hasOwnProperty.call(obj, key)) { var desc = Object.defineProperty && Object.getOwnPropertyDescriptor ? Object.getOwnPropertyDescriptor(obj, key) : {}; if (desc.get || desc.set) { Object.defineProperty(newObj, key, desc); } else { newObj[key] = obj[key]; } } } } newObj.default = obj; return newObj; } }

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function registerAppInfo(app, info) {
  app.set("host", info.host);
  app.set("port", info.port);
  app.locals.title = info.name;
  app.locals.version = info.version;
  app.locals.description = info.description;
  app.locals.author = info.author;
}

function registerRoutes(app) {
  app.use("/", _routes.default);
}

function registerApps(app, info) {
  _raven.default.config(process.env.APP_SENTRY_DSN).install(); // This request handler must be the first middleware on the app


  app.use(_raven.default.requestHandler());
  app.use((0, _cors.default)());
  app.use((0, _helmet.default)());
  app.use((0, _compression.default)());
  app.use((0, _morgan.default)("tiny", {
    stream: _logger.logStream
  }));
  app.use(_bodyParser.default.json());
  app.use(errorHandler.bodyParser);
  app.use(_json.default);
}

function registerMiddlewares(app) {
  app.use(_raven.default.errorHandler());
  app.use(errorHandler.genericErrorHandler);
  app.use(errorHandler.methodNotAllowed);
}

function registerAuthStrategy(app) {
  if (_package.default.junsApi.auth) {
    (0, _passport.default)(app);
    const authController = new _auth.default();

    _logger.default.info(authController.getAllroutes());

    _logger.default.info(JSON.stringify(authController.getAllroutes()));

    app.use("/auth", authController.getAllroutes());

    _logger.default.info(`Auth Strategy Registred`);
  }
}

function registerFileUploadStrategy(app) {
  if (_package.default.junsApi.fileUpload) {
    (0, _fileUpload.default)(app, _package.default.junsApi.fileUpload);

    _logger.default.info(`File Upload Strategy Registred`);
  }
}

function buildApp() {
  const app = (0, _express.default)();
  const appInfo = (0, _domain.getAppInfos)();
  registerAppInfo(app, appInfo);
  registerApps(app, appInfo);
  registerRoutes(app);
  registerAuthStrategy(app);
  registerMiddlewares(app);
  registerFileUploadStrategy(app);
  return app;
}

function startApp(app) {
  app.listen(app.get("port"), app.get("host"), () => {
    _logger.default.info(`Server started at http://${app.get("host")}:${app.get("port")}/api`);
  });
}

var _default = {
  buildApp,
  startApp
};
exports.default = _default;