"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = _default;

var _passport = _interopRequireDefault(require("passport"));

var _passportJwt = _interopRequireDefault(require("passport-jwt"));

var _passportLocal = _interopRequireDefault(require("passport-local"));

var _package = _interopRequireDefault(require("../../package"));

var _auth = _interopRequireDefault(require("./auth/auth.service"));

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _default(app) {
  const LocalStrategy = _passportLocal.default.Strategy;
  const ExtractJWT = _passportJwt.default.ExtractJwt;
  const JWTStrategy = _passportJwt.default.Strategy;
  const localStrategyOptions = {
    usernameField: _package.default.junsApi.auth.usernameField,
    passwordField: _package.default.junsApi.auth.passwordField
  };
  const JWTStrategyOptions = {
    jwtFromRequest: ExtractJWT.fromAuthHeaderAsBearerToken(),
    secretOrKey: process.env.APP_AUTH_SECRET
  };

  _passport.default.serializeUser(function (user, done) {
    done(null, user);
  });

  _passport.default.deserializeUser(function (user, done) {
    done(null, user);
  });

  _passport.default.use(new LocalStrategy(localStrategyOptions, function (email, password, cb) {
    const authService = new _auth.default();
    return authService.login(email, password).then(user => {
      if (!user) {
        return cb(null, false, {
          message: 'Incorrect email or password.'
        });
      }

      return cb(null, user, {
        message: 'Logged In Successfully'
      });
    }).catch(err => {
      return cb(err);
    });
  }));

  _passport.default.use(new JWTStrategy(JWTStrategyOptions, function (jwtPayload, cb) {
    const authService = new _auth.default();
    return authService.buscarPorId(jwtPayload.id).then(user => {
      delete user[localStrategyOptions.passwordField];
      return cb(null, user);
    }).catch(err => {
      return cb(err);
    });
  }));

  app.use(_passport.default.initialize());
  app.use(_passport.default.session());
}